<?php

namespace SGalinski\SgMail\Form\NodeExpansion;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Backend\Form\AbstractNode;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Utility\LocalizationUtility;

/**
 * Renders additional TCA field information.
 */
class FieldInformation extends AbstractNode {

	/**
	 * @return array Result array
	 */
	public function render(): array {
		$result = $this->initializeResultArray();
		$options = $this->data['renderData']['fieldInformationOptions']
			?? $this->data['renderData']['fieldWizardOptions'];

		if (
			!isset($options['text'])
			&& (!isset($options['parentFields'], $options['parentTable'], $options['parentUidField']))
		) {
			return $result;
		}

		$text = \trim($options['text'] ?? '');

		if ($text === '') {
			return $result;
		}

		if (\strpos($text, 'LLL') === 0) {
			$text = LocalizationUtility::translate($text);
		}

		$tagOpen = '<span>';
		$tagClose = '</span>';

		if (isset($options['tag'])) {
			$tag = \trim(\str_replace(['<', '>'], '', $options['tag']));
			$tagSplit = GeneralUtility::trimExplode(' ', $tag);
			$tagName = $tagSplit[0];

			if ($tagName !== '') {
				$tagOpen = '<' . $tag . '>';
				$tagClose = '</' . $tagName . '>';
			}
		}

		$result['html'] = '<div>' . $tagOpen . $text . $tagClose . '</div>';

		return $result;
	}
}
